
CREATE OR REPLACE FUNCTION documentdb_api.list_databases(
    p_list_databases_spec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $$command_list_databases$$;
DROP FUNCTION IF EXISTS documentdb_api_internal.delete_expired_rows_for_index(
    IN collection_id bigint,
    IN index_id bigint,
    IN index_key documentdb_core.bson,
    IN index_pfe documentdb_core.bson,
    IN current_datetime bigint,
    IN index_expiry int,
    IN ttl_batch_size int,
    IN shard_id bigint);
CREATE OR REPLACE PROCEDURE documentdb_api_internal.delete_expired_rows(IN p_batch_size int default -1)
    LANGUAGE c
AS 'MODULE_PATHNAME', $procedure$delete_expired_rows$procedure$;
COMMENT ON PROCEDURE documentdb_api_internal.delete_expired_rows(int)
    IS 'Drops expired rows from applicable collections based on TTL indexes.';
DROP FUNCTION IF EXISTS documentdb_api_internal.current_op_aggregation;
CREATE OR REPLACE FUNCTION documentdb_api_internal.current_op_aggregation(p_spec documentdb_core.bson, OUT document documentdb_core.bson)
RETURNS SETOF documentdb_core.bson
 LANGUAGE c
 VOLATILE STRICT ROWS 100
AS 'MODULE_PATHNAME', $function$command_current_op_aggregation$function$;
DROP FUNCTION IF EXISTS documentdb_api_internal.current_op_worker;
CREATE OR REPLACE FUNCTION documentdb_api_internal.current_op_worker(p_spec documentdb_core.bson, OUT document documentdb_core.bson)
RETURNS documentdb_core.bson
 LANGUAGE c
 VOLATILE STRICT
AS 'MODULE_PATHNAME', $function$command_current_op_worker$function$;
DROP FUNCTION IF EXISTS documentdb_api.current_op_command;
CREATE OR REPLACE FUNCTION documentdb_api.current_op_command(p_spec documentdb_core.bson, OUT document documentdb_core.bson)
RETURNS documentdb_core.bson
LANGUAGE c
VOLATILE STRICT
AS 'MODULE_PATHNAME', $function$command_current_op$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.query_match_support(internal)
 RETURNS internal
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $$query_match_support$$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_query_match(documentdb_core.bson, documentdb_core.bson)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
 SUPPORT documentdb_api_catalog.query_match_support
AS 'MODULE_PATHNAME', $function$bson_query_match$function$;
CREATE OR REPLACE FUNCTION documentdb_api_catalog.bson_true_match(documentdb_core.bson)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$bson_true_match$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.bson_query_match(document documentdb_core.bson, query documentdb_core.bson, collationString text, variableSpec documentdb_core.bson)
 RETURNS bool
 LANGUAGE c
 IMMUTABLE PARALLEL SAFE
AS 'MODULE_PATHNAME', $function$bson_query_match$function$;
-- Schedule TTL Cron job to prune TTL indexes on every documentdb instance.
DO LANGUAGE plpgsql $cmd$
BEGIN
    IF NOT EXISTS(SELECT 1 FROM cron.job where jobname = 'documentdb_ttl_task') THEN
        PERFORM cron.schedule('documentdb_ttl_task', '* * * * *', $$CALL documentdb_api_internal.delete_expired_rows();$$);
    END IF;
END;
$cmd$;
